package Acme::PERLANCAR::Test::Versioning;

our $DATE = '2018-05-08'; # DATE
our $DIST = 'Acme-PERLANCAR-Test-Versioning'; # DIST
our $VERSION = '1.0'; # VERSION

1;
# ABSTRACT: Test versioning

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::PERLANCAR::Test::Versioning - Test versioning

=head1 VERSION

This document describes version 1.0 of Acme::PERLANCAR::Test::Versioning (from Perl distribution Acme-PERLANCAR-Test-Versioning), released on 2018-05-08.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-PERLANCAR-Test-Versioning>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Test-Versioning>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-PERLANCAR-Test-Versioning>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
